@@ -4,11 +4,12 @@
 package Maplat::Web::StaticCache;
 use strict;
 use warnings;
+use 5.010;
 
 use base qw(Maplat::Web::BaseModule);
 use Maplat::Helpers::FileSlurp qw(slurpBinFile);
 
-our $VERSION = 0.993;
+our $VERSION = 0.994;
 
 
 use Carp;
@@ -73,28 +74,35 @@ sub load_dir {
             next;
         }
 
-        next if($fname !~ /(.*)\.([a-zA-Z0-9]*)/);
-        my ($kname, $type) = ($1, $2);
-        if($type =~ /jpg/i) {
-            $type = "image/jpeg";
-        } elsif($type =~ /bmp/i) {
-            $type = "image/bitmap";
-        } elsif($type =~ /htm/i) {
-            $type = "text/html";
-        } elsif($type =~ /css/i) {
-            $type = "text/css";
-        } elsif($type =~ /js/i) {
-            $type = "application/javascript";
+        if($fname =~ /(.*)\.([a-zA-Z0-9]*)/) {
+            my ($kname, $type) = ($1, $2);
+            given($type) {
+                when(/jpg/i) {
+                    $type = "image/jpeg";
+                }
+                when(/bmp/i) {
+                    $type = "image/bitmap";
+                }
+                when(/htm/i) {
+                    $type = "text/html";
+                }
+                when(/css/i) {
+                    $type = "text/css";
+                }
+                when(/js/i) {
+                    $type = "application/javascript";
+                }
+            }
+            
+            my $data = slurpBinFile($nfname);
+            my %entry = (name   => $kname,
+                        fullname=> $nfname,
+                        type    => $type,
+                        data    => $data,
+                        );
+            $self->{cache}->{$basewebpath . $fname} = \%entry; # Store under full name
+            $fcount++;
         }
-        
-        my $data = slurpBinFile($nfname);
-        my %entry = (name   => $kname,
-                    fullname=> $nfname,
-                    type    => $type,
-                    data    => $data,
-                    );
-        $self->{cache}->{$basewebpath . $fname} = \%entry; # Store under full name
-        $fcount++;
     }
     closedir($dfh);
     return $fcount;
